import {
  csv,
  select,
  selectAll,
  scaleLinear,
  json,
  geoAlbersUsa,
} from 'd3';
import { feature } from 'topojson';

const width = window.innerWidth;
const height = window.innerHeight;

const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const projection = d3
  .geoAlbersUsa()
  .translate([width / 2, height / 2])
  .scale(width);
const path = d3.geoPath().projection(projection);

json(
  'https://unpkg.com/us-atlas@3.0.0/states-10m.json'
).then((us) => {
  // Converting the topojson to geojson.
  console.log(us);
  const us1 = feature(us, us.objects.states);
  svg
    .append('g')
    .selectAll('path')
    .data(us1.features)
    .enter()
    .append('path')
    .attr('d', path)
    .style('fill', '#ccc')
    .style('stroke', '#fff')
    .style('stroke-width', '0.5px');

  csv('citydata.csv').then((cities) => {
    console.log(cities);
    // Draw the cities
    let cityCircles = svg
      .append('g')
      .selectAll('circle')
      .data(cities)
      .enter()
      .append('circle')
      .attr('class', 'city')
      .attr('cx', (d) => {
        return projection([d.lon, d.lat])[0];
      })
      .attr('cy', (d) => {
        return projection([d.lon, d.lat])[1];
      })
      .attr('r', 5)
      .style('fill', 'red')
      .style('stroke', '#fff')
      .style('stroke-width', '1px')
      .on('mouseover', function (d) {
        d3.select(this)
          .transition()
          .duration(200)
          .attr('r', 10)
          .style('fill', 'blue');
      })
      .on('mouseout', function (d) {
        d3.select(this)
          .transition()
          .duration(200)
          .attr('r', 5)
          .style('fill', 'red');
      })
      .on('click', function (d) {
        //console.log(d.name + " (" + d.lat + ", " + d.lon + ")");
        console.log(d.srcElement.__data__.flow);
        selectAll(".line").remove();
        let clickedCity = d3.select(this);
        //console.log(clickedCity);
        let clickedCityCoords = [
          parseFloat(clickedCity.attr('cx')),
          parseFloat(clickedCity.attr('cy')),
        ];

        cityCircles.each(function (
          otherCityData
        ) {
          if (otherCityData !== d) {
            let otherCity = d3.select(this);
            let otherCityCoords = [
              parseFloat(otherCity.attr('cx')),
              parseFloat(otherCity.attr('cy')),
            ];

            svg
              .append('line')
              .attr('class', 'line')
              .attr('x1', clickedCityCoords[0])
              .attr('y1', clickedCityCoords[1])
              .attr('x2', otherCityCoords[0])
              .attr('y2', otherCityCoords[1])
              .style('stroke', 'black')
              .style('stroke-width', d.srcElement.__data__.flow)
              .style('opacity', 0.5);
          }
        });
      });
  });
});

// csv("citydata.csv").then(cities => {

//     // Draw the cities
//     svg.append("g")
//       .selectAll("circle")
//       .data(cities)
//       .enter()
//       .append("circle")
//       .attr("class", "city")
//       .attr("cx", d => { return projection([d.lon, d.lat])[0]; })
//       .attr("cy", d => { return projection([d.lon, d.lat])[1]; })
//       .attr("r", 5)
//       .style("fill", "red")
//       .style("stroke", "#fff")
//       .style("stroke-width", "1px")
//       .on("mouseover", function(d) {
//         d3.select(this)
//           .transition()
//           .duration(200)
//           .attr("r", 10)
//           .style("fill", "blue");
//       })
//       .on("mouseout", function(d) {
//         d3.select(this)
//           .transition()
//           .duration(200)
//           .attr("r", 5)
//           .style("fill", "red");
//       })
//       .on("click", function(d) {
//         //console.log(d.name + " (" + d.lat + ", " + d.lon + ")");
//       console.log(d.srcElement.__data__);

//       });
//   });
